@@ -29,9 +29,12 @@ def test_coords(
                 a.text == 'N85,8598654')
     with check:
         assert lat0 == IsPartialDict(labelName='coords', text='N85,8598654',
-                                     properties=IsPartialDict(ref_lat='N', val_lat='85,8598654'))
+                                     properties=IsPartialDict(ref_lat='N', val_lat='85,8598654',
+                                                              pattern_name='ref_lat'))
 
     lat1 = next(a.dict(exclude_none=True, exclude_unset=True) for a in doc0.annotations if
                 a.text == '85,8598654N')
     with check:
-        assert lat1 == IsPartialDict(labelName='coords', text='85,8598654N', properties=IsPartialDict(ref_lat='N', val_lat='85,8598654'))
+        assert lat1 == IsPartialDict(labelName='coords', text='85,8598654N',
+                                     properties=IsPartialDict(ref_lat='N', val_lat='85,8598654',
+                                                              pattern_name='ref_lat_DEVANT'))
